netapp_ontap.models.mongo_db_on_san_dataset API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.mongo_db_on_san_dataset`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class MongoDbOnSanDatasetSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the MongoDbOnSanDataset object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `element_count: Size GET POST`

    The number of storage elements (LUNs for SAN) of the database to maintain. Must be an even number between 2 and 16. Odd numbers will be rounded up to the next even number within range.

  `replication_factor: Size GET POST`

    The number of data bearing members of the replicaset, including 1 primary and at least 1 secondary.

  `size: Size GET POST PATCH`

    The size of the database. Usage: {<integer>[KB|MB|GB|TB|PB]}

  `storage_service: MongoDbOnSanDatasetStorageService GET POST PATCH`

    The storage_service field of the mongo_db_on_san_dataset.